@@ -353,12 +353,18 @@ void print_usage(FILE *stream,int exit_code) {
 	fprintf(stream, "   TARGET must be exactly one of these:\n");
 	fprintf(stream, "      -p, --pid=N        pid of the process\n");
 	fprintf(stream, "      -e, --exe=FILE     name of the executable program file\n");
-	fprintf(stream, "      -P, --path=PATH    absolute path name of the executable program file\n");
+        fprintf(stream, "                         The -e option only works when\n");
+        fprintf(stream, "                         cpulimit is run with admin rights.\n");
+	fprintf(stream, "      -P, --path=PATH    absolute path name of the\n");
+        fprintf(stream, "                         executable program file\n");
 	fprintf(stream, "   OPTIONS\n");
         fprintf(stream, "      -b  --background   run in background\n");
-	fprintf(stream, "      -l, --limit=N      percentage of cpu allowed from 0 to 100 (mandatory)\n");
+	fprintf(stream, "      -l, --limit=N      percentage of cpu allowed from 1 up.\n");
+        fprintf(stream, "                         Usually 1 - 100, but can be higher\n");
+        fprintf(stream, "                         on multi-core CPUs (mandatory)\n");
 	fprintf(stream, "      -v, --verbose      show control statistics\n");
-	fprintf(stream, "      -z, --lazy         exit if there is no suitable target process, or if it dies\n");
+	fprintf(stream, "      -z, --lazy         exit if there is no suitable target process,\n");
+        fprintf(stream, "                         or if it dies\n");
 	fprintf(stream, "      -h, --help         display this help and exit\n");
 	exit(exit_code);
 }
